@@ -710,9 +710,7 @@ try_user_add_again:
 	af = gdm_safe_fopen_ap (d->userauth);
     }
 
-    /* Set to NULL, because can goto try_user_add_again. */
     g_free (authdir);
-    authdir = NULL;
 
     if G_UNLIKELY (af == NULL) {
 	/* Really no need to clean up here - this process is a goner anyway */
@@ -725,11 +723,7 @@ try_user_add_again:
 	d->userauth = NULL;
 
 	umask (022);
-	/* check if authdir is fallback dir if not try it with the fallback dir */
-	if (strcmp(gdm_get_value_string (GDM_KEY_USER_AUTHDIR_FALLBACK),authdir) != 0 ){
-		authdir = gdm_get_value_string (GDM_KEY_USER_AUTHDIR_FALLBACK); 
-		goto try_user_add_again;
-	}
+
 	if ( ! d->authfb) {
 		automatic_tmp_dir = TRUE;
 		goto try_user_add_again;
