@@ -52,6 +52,7 @@ static GtkWidget  *pam_entry = NULL;
 static GtkWidget  *user_list = NULL;
 
 static gboolean    selecting_user = FALSE;
+static gchar      *selected_user = NULL;
 
 enum
 {
@@ -61,6 +62,24 @@ enum
 	GREETER_ULIST_ACTIVE_COLUMN
 };
 
+void
+greeter_item_ulist_unset_selected_user (void)
+{
+	GtkTreeSelection *selection;
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_list));
+	gtk_tree_selection_unselect_all (selection);
+
+	if (selected_user != NULL)
+		g_free (selected_user);
+	selected_user = NULL;
+}
+
+gchar *
+greeter_item_ulist_get_selected_user (void)
+{
+	return selected_user;
+}
+
 static void
 check_for_displays (void)
 {
@@ -69,6 +88,10 @@ check_for_displays (void)
 	char  *auth_cookie = NULL;
 	int    i;
 
+	/*
+	 * Might be nice to move this call into read_config() so that it happens
+	 * on the same socket call as reading the configuration.
+	 */
 	ret = gdmcomm_call_gdm (GDM_SUP_ATTACHED_SERVERS, auth_cookie, "2.2.4.0", 5);
 	if (ve_string_empty (ret) || strncmp (ret, "OK ", 3) != 0) {
 		g_free (ret);
@@ -166,6 +189,15 @@ greeter_populate_user_list (GtkTreeModel *tm)
 	}
 }
 
+void 
+greeter_item_ulist_select_user (gchar *login)
+{
+	printf ("%c%c%c%s\n", STX, BEL,
+		GDM_INTERRUPT_SELECT_USER, login);
+
+	fflush (stdout);
+}
+
 static void
 user_selected (GtkTreeSelection *selection, gpointer data)
 {
@@ -186,9 +218,10 @@ user_selected (GtkTreeSelection *selection, gpointer data)
 				if (pamlabel == NULL) {
 					gdm_common_warning ("Theme broken: must have pam-message label!");
 				}
-				printf ("%c%c%c%s\n", STX, BEL,
-					GDM_INTERRUPT_SELECT_USER, login);
-				fflush (stdout);
+				greeter_item_ulist_select_user (login);
+				if (selected_user != NULL)
+					g_free (selected_user);
+				selected_user = g_strdup (login);
 			}
 		}
 	}
@@ -321,8 +354,6 @@ greeter_item_ulist_setup (void)
 			force_no_tree_separators (user_list);
 
 			greeter_generate_userlist (user_list);
-			if ( ! DOING_GDM_DEVELOPMENT)
-				greeter_item_ulist_disable ();
 
 			/* Reset size of the widget canvas item so it
 			 * is the same size as the userlist.  This
